==> estateplat-common-1.2.3-20181019.024348-201-sources.jar: cn/gtmap/estateplat/model/exchange/national/InfApplyMaterial.java <==
package cn.gtmap.estateplat.model.exchange.national;
/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/9/4
 * @description 申请材料信息表
 */

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;
@Table(name = "inf_apply_material")
public class InfApplyMaterial {
    @Id
    private String no;//主键唯一标识
    private String internal_no;//全省唯一办件编号
    private String attafkonlyno;//所属对象关联唯一标识
    private String sj_file_name;//材料名称
    private Integer sj_no;//材料份数
    private String sj_file_if;//材料是否必须
    private String sj_file_statu;//材料收取情况
    private String if_ec_page;//是否需要电子版
    private String ord;//收件材料序号
    private String data_sources;//数据来源
    private Date up_date;//数据推送时间
    private Date sync_date;//信息同步读取时间
    private String sync_sign;//信息同步标志
    private String sync_error_desc;//信息同步错误原因

    private String org_id;//部门编码
    private String sj_taketype;//材料收取方式
    private Date sj_taketime;//材料收取时间
    private String remark;//备注


    public String getNo() {
        return no;
    }

    public void setNo(String no) {
        this.no = no;
    }

    public String getInternal_no() {
        return internal_no;
    }

    public void setInternal_no(String internal_no) {
        this.internal_no = internal_no;
    }

    public String getAttafkonlyno() {
        return attafkonlyno;
    }

    public void setAttafkonlyno(String attafkonlyno) {
        this.attafkonlyno = attafkonlyno;
    }

    public String getSj_file_name() {
        return sj_file_name;
    }

    public void setSj_file_name(String sj_file_name) {
        this.sj_file_name = sj_file_name;
    }

    public Integer getSj_no() {
        return sj_no;
    }

    public void setSj_no(Integer sj_no) {
        this.sj_no = sj_no;
    }

    public String getSj_file_if() {
        return sj_file_if;
    }

    public void setSj_file_if(String sj_file_if) {
        this.sj_file_if = sj_file_if;
    }

    public String getSj_file_statu() {
        return sj_file_statu;
    }

    public void setSj_file_statu(String sj_file_statu) {
        this.sj_file_statu = sj_file_statu;
    }

    public String getIf_ec_page() {
        return if_ec_page;
    }

    public void setIf_ec_page(String if_ec_page) {
        this.if_ec_page = if_ec_page;
    }

    public String getOrd() {
        return ord;
    }

    public void setOrd(String ord) {
        this.ord = ord;
    }

    public String getData_sources() {
        return data_sources;
    }

    public void setData_sources(String data_sources) {
        this.data_sources = data_sources;
    }

    public Date getUp_date() {
        return up_date;
    }

    public void setUp_date(Date up_date) {
        this.up_date = up_date;
    }

    public Date getSync_date() {
        return sync_date;
    }

    public void setSync_date(Date sync_date) {
        this.sync_date = sync_date;
    }

    public String getSync_sign() {
        return sync_sign;
    }

    public void setSync_sign(String sync_sign) {
        this.sync_sign = sync_sign;
    }

    public String getSync_error_desc() {
        return sync_error_desc;
    }

    public void setSync_error_desc(String sync_error_desc) {
        this.sync_error_desc = sync_error_desc;
    }

    public String getOrg_id() {
        return org_id;
    }

    public void setOrg_id(String org_id) {
        this.org_id = org_id;
    }

    public String getSj_taketype() {
        return sj_taketype;
    }

    public void setSj_taketype(String sj_taketype) {
        this.sj_taketype = sj_taketype;
    }

    public Date getSj_taketime() {
        return sj_taketime;
    }

    public void setSj_taketime(Date sj_taketime) {
        this.sj_taketime = sj_taketime;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
}

==> estateplat-common-1.2.4-20190306.070641-114-sources.jar: cn/gtmap/estateplat/model/exchange/national/InfApplyMaterial.java <==
package cn.gtmap.estateplat.model.exchange.national;
/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/9/4
 * @description 申请材料信息表
 */

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;
@Table(name = "inf_apply_material")
public class InfApplyMaterial {
    @Id
    private String no;//主键唯一标识
    private String internal_no;//全省唯一办件编号
    private String attafkonlyno;//所属对象关联唯一标识
    private String sj_file_name;//材料名称
    private Integer sj_no;//材料份数
    private String sj_file_if;//材料是否必须
    private String sj_file_statu;//材料收取情况
    private String if_ec_page;//是否需要电子版
    private String ord;//收件材料序号
    private String data_sources;//数据来源
    private Date up_date;//数据推送时间
    private Date sync_date;//信息同步读取时间
    private String sync_sign;//信息同步标志
    private String sync_error_desc;//信息同步错误原因

    private String org_id;//部门编码
    private String sj_taketype;//材料收取方式
    private Date sj_taketime;//材料收取时间
    private String remark;//备注
    private String proid;//业务号


    public String getNo() {
        return no;
    }

    public void setNo(String no) {
        this.no = no;
    }

    public String getInternal_no() {
        return internal_no;
    }

    public void setInternal_no(String internal_no) {
        this.internal_no = internal_no;
    }

    public String getAttafkonlyno() {
        return attafkonlyno;
    }

    public void setAttafkonlyno(String attafkonlyno) {
        this.attafkonlyno = attafkonlyno;
    }

    public String getSj_file_name() {
        return sj_file_name;
    }

    public void setSj_file_name(String sj_file_name) {
        this.sj_file_name = sj_file_name;
    }

    public Integer getSj_no() {
        return sj_no;
    }

    public void setSj_no(Integer sj_no) {
        this.sj_no = sj_no;
    }

    public String getSj_file_if() {
        return sj_file_if;
    }

    public void setSj_file_if(String sj_file_if) {
        this.sj_file_if = sj_file_if;
    }

    public String getSj_file_statu() {
        return sj_file_statu;
    }

    public void setSj_file_statu(String sj_file_statu) {
        this.sj_file_statu = sj_file_statu;
    }

    public String getIf_ec_page() {
        return if_ec_page;
    }

    public void setIf_ec_page(String if_ec_page) {
        this.if_ec_page = if_ec_page;
    }

    public String getOrd() {
        return ord;
    }

    public void setOrd(String ord) {
        this.ord = ord;
    }

    public String getData_sources() {
        return data_sources;
    }

    public void setData_sources(String data_sources) {
        this.data_sources = data_sources;
    }

    public Date getUp_date() {
        return up_date;
    }

    public void setUp_date(Date up_date) {
        this.up_date = up_date;
    }

    public Date getSync_date() {
        return sync_date;
    }

    public void setSync_date(Date sync_date) {
        this.sync_date = sync_date;
    }

    public String getSync_sign() {
        return sync_sign;
    }

    public void setSync_sign(String sync_sign) {
        this.sync_sign = sync_sign;
    }

    public String getSync_error_desc() {
        return sync_error_desc;
    }

    public void setSync_error_desc(String sync_error_desc) {
        this.sync_error_desc = sync_error_desc;
    }

    public String getOrg_id() {
        return org_id;
    }

    public void setOrg_id(String org_id) {
        this.org_id = org_id;
    }

    public String getSj_taketype() {
        return sj_taketype;
    }

    public void setSj_taketype(String sj_taketype) {
        this.sj_taketype = sj_taketype;
    }

    public Date getSj_taketime() {
        return sj_taketime;
    }

    public void setSj_taketime(Date sj_taketime) {
        this.sj_taketime = sj_taketime;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}
